# -*- coding: utf-8 -*-
import pprint
import os

import pytest

def test_env_absent():
    # If the env var is already set, the environ
    # variables should not be affected.
    os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "Set by test"
    original_vars = dict(os.environ)

    import pygamesilent

    assert dict(os.environ) == original_vars



# -*- coding: utf-8 -*-

import os

import pytest

def test_env_absent():
    # Even if the env var is not initially set, the environ
    # variables should not be affected.
    assert "PYGAME_HIDE_SUPPORT_PROMPT" not in os.environ
    import pygamesilent
    assert "PYGAME_HIDE_SUPPORT_PROMPT" not in os.environ



# -*- coding: utf-8 -*-

import os as _os

# PyGame will suppress output if this environment variable is set.
_ENVIRONMENT_VAR_NAME = "PYGAME_HIDE_SUPPORT_PROMPT"

# Don't interfere if someone has already set it.
_ADD_VAR = _ENVIRONMENT_VAR_NAME not in _os.environ

if _ADD_VAR:
    _os.environ[_ENVIRONMENT_VAR_NAME] = "Added by pygamesilent"

try:
    from pygame import *
except ModuleNotFoundError:
    from warnings import warn as _warn
    _warn("pygamesilent requires pygame to be installed too.")
    raise

try:
    # Pretend to be pygame's version number.
    from pygame import __version__
    # This wasn't imported above, because of the leading underscores.
except ImportError:
    # If some version of pygame doesn't export it, neither will we.
    pass

if _ADD_VAR:
    del _os.environ[_ENVIRONMENT_VAR_NAME]




# -*- coding: utf-8 -*-

from pprint import pprint
import pytest

def test_exports():
    # Modules should export identical names.

    import pygamesilent
    import pygame

    # Check an arbitrary export is the same.
    assert pygame.draw == pygamesilent.draw

    # Check version numbers match.
    assert pygamesilent.__version__ == pygame.__version__

    # Check list of exports match:
    pygame_exports = set(
        entry for entry in dir(pygame) if not entry.startswith("_"))
    pygamesilent_exports = set(
        entry for entry in dir(pygamesilent) if not entry.startswith("_"))

    assert pygame_exports == pygamesilent_exports





"""  pygamesilent setup module.
Cribbed from: https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='pygamesilent',
    version='0.1.6',
    description='Shim around PyGame to hide "Hello" message on import.',
    long_description=long_description,
    url='https://github.com/Julian-O/pygamesilent',
    author='Julian-O',
    author_email='pygamesilent@somethinkodd.com',
    long_description_content_type="text/markdown",
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: pygame'
    ],
    keywords='pygame shim',
    packages=['pygamesilent'],
    package_dir={'': 'src'},    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*, <4',
    install_requires=['pygame'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). Users will be able to install these using the "extras"
    # syntax, for example:
    #
    #   $ pip install sampleproject[dev]
    #
    # Similar to `install_requires` above, these must be valid existing
    # projects.
    extras_require={  # Optional
        'dev': ['check-manifest'],
        'test': ['pytest', 'pytest-cov'],
    },

    # List additional URLs that are relevant to your project as a dict.
    #
    # This field corresponds to the "Project-URL" metadata fields:
    # https://packaging.python.org/specifications/core-metadata/#project-url-multiple-use
    #
    # Examples listed include a pattern for specifying where the package tracks
    # issues, where the source is hosted, where to say thanks to the package
    # maintainers, and where to support the project financially. The key is
    # what's used to render the link text on PyPI.
    project_urls={  # Optional
        'Source': 'https://github.com/Julian-O/pygamesilent/',
        'PyGame Info': 'https://pygame.org',
    },
)



# -*- coding: utf-8 -*-

try:
    from io import StringIO
except:
    # Python 2.
    from cStringIO import StringIO
import sys

import pytest


def test_import_is_silentp():
    old_stdout = sys.stdout
    sys.stdout = mystdout = StringIO()

    import pygamesilent

    sys.stdout = old_stdout

    assert len(mystdout.getvalue()) == 0, \
        "Unexpected output: %s" % mystdout.getvalue()
